@@ -2,7 +2,7 @@ import yaml
 import os
 from pathlib import Path
 from shutil import copyfile
-from t2wml.wikification.utility_functions import add_nodes_from_file
+from t2wml.wikification.utility_functions import add_entities_from_file
 from t2wml.wikification.item_table import Wikifier
 from t2wml.spreadsheets.sheet import Sheet, SpreadsheetFile
 from t2wml.mapping.statement_mapper import YamlMapper
@@ -14,13 +14,31 @@ from t2wml.settings import DEFAULT_SPARQL_ENDPOINT
     
 
 class Project:
-    def __init__(self, directory, title="Untitled", data_files=None, yaml_files=None, wikifier_files=None, 
+    def __init__(self, directory, title=None, data_files=None, yaml_files=None, wikifier_files=None, 
                        entity_files=None,
                    yaml_sheet_associations=None, specific_wikifiers=None,
                    sparql_endpoint=DEFAULT_SPARQL_ENDPOINT, warn_for_empty_cells=False):
+        """
+        Args:
+            directory ([str, None]): Project directory. All project files must be contained in this directory or it's sub directories
+            title ([str], optional): Project title. When None, defaults to name of folder at end of directory path
+            data_files ([list], optional): Project's data files. When None, defaults to empty array. 
+            yaml_files ([list], optional): Project's yaml files. When None, defaults to empty array. 
+            wikifier_files ([list], optional): Project's wikifier files. When None, defaults to empty array. 
+            entity_files ([list], optional): Project's entity files. When None, defaults to empty array. 
+            yaml_sheet_associations ([dict], optional): [description]. When None, defaults to empty dictionary.
+            specific_wikifiers ([dict], optional): wikifiers to be applied only to specific data files/sheets.  When None, defaults to empty dictionary.
+            sparql_endpoint ([str], optional): sparql endpoint for attempting to fetch entities not in entity files. Defaults to DEFAULT_SPARQL_ENDPOINT.
+            warn_for_empty_cells (bool, optional): Project setting for whether empty cells in qualifier region are treated as an error. Defaults to False.
+
+        Raises:
+            ValueError: [description]
+        """        
         if not os.path.isdir(directory):
             raise ValueError("Project must be created with a valid project directory")
         self.directory=directory
+        if title is None:
+            title=Path(directory).stem
         self.title=title
         self.data_files=data_files or []
         self.yaml_files=yaml_files or []
@@ -135,8 +153,10 @@ class Project:
         return file_path
     
     def save(self):
-        proj_file_text=(yaml.dump(self.__dict__))
-        proj_file_path=os.path.join(self.directory, ".t2wmlproj")
+        output_dict=dict(self.__dict__)
+        output_dict.pop('directory')
+        proj_file_text=(yaml.dump(output_dict))
+        proj_file_path=os.path.join(self.directory, "project.t2wml")
         with open(proj_file_path, 'w', encoding="utf-8") as f:
             f.write(proj_file_text)
         return proj_file_path
@@ -144,9 +164,9 @@ class Project:
     @classmethod
     def load(cls, filepath):
         if os.path.isdir(filepath):
-            filepath=os.path.join(filepath, ".t2wmlproj")
+            filepath=os.path.join(filepath, "project.t2wml")
         if not os.path.isfile(filepath):
-            raise FileNotFoundError("Could not find .t2wmlproj file")
+            raise FileNotFoundError("Could not find project.t2wml file")
         try:
             with open(filepath, 'r', encoding="utf-8") as f:
                 proj_input=yaml.safe_load(f.read())
@@ -169,8 +189,8 @@ class ProjectRunner():
         p=Project.load(filepath)
         return cls(p)
 
-    def _add_nodes_from_file(self, f):
-        add_nodes_from_file(os.path.join(self.project.directory, f))
+    def _add_entities_from_file(self, f):
+        add_entities_from_file(os.path.join(self.project.directory, f))
     def _add_file_to_wikifier(self, wikifier, f):
         wikifier.add_file(os.path.join(self.project.directory, f))
     def _handle_specific_wikifiers(self, wikifier, data_file, sheet_name):
@@ -189,7 +209,7 @@ class ProjectRunner():
             
     def generate_single_knowledge_graph(self, data_file, sheet_name, yaml, wikifier_file=None):
         for f in self.project.entity_files:
-            self._add_nodes_from_file(f)
+            self._add_entities_from_file(f)
         wikifier=Wikifier()
         if wikifier_file:
             self._add_file_to_wikifier(wikifier, wikifier_file)
@@ -206,7 +226,7 @@ class ProjectRunner():
     def generate_all_knowledge_graphs(self):
         knowledge_graphs=[]
         for f in self.project.entity_files:
-            self._add_nodes_from_file(f)
+            self._add_entities_from_file(f)
 
         for data_file in self.project.data_files:
             data_file=os.path.join(self.project.directory, data_file)
